# Pending AI CLI

Command-line interface for accessing the Pending AI Platform - a comprehensive drug discovery platform
enabled by scalable artificial intelligence and quantum mechanics.

## Getting Started

Usage of the Pending AI CLI requires

* an account for the **Pending AI Platform** and
* a locally installed Python version `>=3.9`.

Once installed with

```sh
pip install pendingai
```
successful installation can be verified with

```bash
pendingai --version
```

which is expected to output the name and version of the Pending AI CLI.

## Documentation

Access to the [documentation](https://docs.pending.ai) requires an account for the Pending AI Platform.

## Hidden Options

### Environment

Specify the environment with `--env` or `-e`. Defaults to production, other options are listed
[here](https://github.com/pendingai/pendingai-cli/blob/main/src/pendingai/__init__.py).

### Logging

The verbosity of the logs can be adjusted by providing an int value to the argument `-v`.
Defaults to logging level `ERROR`, values of 1, 2 and 3 change the logging level  to
`WARNING`, `INFO` and `DEBUG`, respectively.

By default, logs are written to a file only. To also show log entries  in the console use the
flag `--log-to-console`.

Acknowledgements

This project includes the [cytoscape.js](https://github.com/cytoscape/cytoscape.js) library for rendering graphs, which is distributed under the MIT license.
The original license text is provided below:

> Copyright (c) 2016-2024, The Cytoscape Consortium.
>
> Permission is hereby granted, free of charge, to any person obtaining a copy of
> this software and associated documentation files (the "Software"), to deal in
> the Software without restriction, including without limitation the rights to
> use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
> of the Software, and to permit persons to whom the Software is furnished to do
> so, subject to the following conditions:
>
> The above copyright notice and this permission notice shall be included in all
> copies or substantial portions of the Software.
>
> THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
> IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
> FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
> AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
> LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
> OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
> SOFTWARE.
